## Pupose

This program parse a .bib file and make new files(index.md, cite.bib) for using zzo theme blog

## Install

You have to install pip before type this command.

```cmd
pip3 install zzo-bibtex-parser
```

## Usage

After install the `zzo-bibtex-parser` package, type this command.
This will generate files in `content/publication/...`

```cmd
zzo --path mybibtex.bib
```
